@@ -8,48 +8,48 @@ class BenchmarkDBResource(object):
     def __init__(self, db_name="performance_test"):
         self.sql = SqlConnection(db_name=db_name)
 
-    def get_search_match_string(self, test_key=None, project_name=None, begin_time=None, end_time=None, test_name=None):
+    def _get_search_match_string(self, test_key=None, project_name=None, begin_time=None, end_time=None, test_name=None):
         search_str = "SELECT * FROM _tests"
         is_first_filter = True
         if project_name is not None:
-            match_string = self.get_project_name_match_string(project_name)
-            search_str = self.generate_filter_string(search_str, match_string, is_first_filter)
+            match_string = self._get_project_name_match_string(project_name)
+            search_str = self._generate_filter_string(search_str, match_string, is_first_filter)
             is_first_filter = False
         if begin_time is not None and end_time is not None:
-            match_string = self.get_search_date_match_string(begin_time, end_time)
-            search_str = self.generate_filter_string(search_str, match_string, is_first_filter)
+            match_string = self._get_search_date_match_string(begin_time, end_time)
+            search_str = self._generate_filter_string(search_str, match_string, is_first_filter)
             is_first_filter = False
         if test_name is not None:
-            match_string = self.get_test_name_match_string(test_name)
-            search_str = self.generate_filter_string(search_str, match_string, is_first_filter)
+            match_string = self._get_test_name_match_string(test_name)
+            search_str = self._generate_filter_string(search_str, match_string, is_first_filter)
         if test_key is not None:
-            match_string = self.get_test_key_match_string(test_key)
-            search_str = self.generate_filter_string(search_str, match_string, is_first_filter)
+            match_string = self._get_test_key_match_string(test_key)
+            search_str = self._generate_filter_string(search_str, match_string, is_first_filter)
 
         return search_str
 
     @staticmethod
-    def get_test_key_match_string(test_key):
+    def _get_test_key_match_string(test_key):
         match_str = "`group_key`='{}'".format(test_key)
         return match_str
 
     @staticmethod
-    def get_project_name_match_string(project_name):
+    def _get_project_name_match_string(project_name):
         match_str = "project_name like '%{}%'".format(project_name)
         return match_str
 
     @staticmethod
-    def get_search_date_match_string(begin_time, end_time):
+    def _get_search_date_match_string(begin_time, end_time):
         match_string = "DATE_FORMAT(start_time,'%Y%m%d') BETWEEN '{}' and '{}'".format(begin_time, end_time)
         return match_string
 
     @staticmethod
-    def get_test_name_match_string(test_name):
+    def _get_test_name_match_string(test_name):
         match_str = "group_name like '%{}%'".format(test_name)
         return match_str
 
     @staticmethod
-    def generate_filter_string(base_string, new_filter, is_first_filter):
+    def _generate_filter_string(base_string, new_filter, is_first_filter):
         if is_first_filter:
             base_string = "{} WHERE ".format(base_string)
         else:
@@ -57,15 +57,15 @@ class BenchmarkDBResource(object):
         search_string = "{} {}".format(base_string, new_filter)
         return search_string
 
-    def get_spec_index(self, main_index, get_index_name):
+    def _get_spec_index(self, main_index, get_index_name):
         command = "SELECT `{}` FROM _tests WHERE `index`={}".format(get_index_name, main_index)
         self.sql.cursor.execute(command)
         tests = self.sql.cursor.fetchall()
         env_index = tests[0][0] if tests else None
         return env_index
 
-    def get_real_time_results(self, test_index, real_timi_mini_index=None):
-        real_time_table_name = self.get_spec_index(test_index, "real_time_index")
+    def _get_real_time_results(self, test_index, real_timi_mini_index=None):
+        real_time_table_name = self._get_spec_index(test_index, "real_time_index")
         if real_timi_mini_index is None:
             command = "SELECT * FROM {}".format(real_time_table_name)
         else:
@@ -84,9 +84,9 @@ class BenchmarkDBResource(object):
     #         print(message)
     #     return results
 
-    def get_test_config(self, index):
+    def _get_test_config(self, index):
         results_dict = dict()
-        config_index = self.get_spec_index(index, "config_index")
+        config_index = self._get_spec_index(index, "config_index")
         command = "SELECT * FROM _configuration WHERE `index`={}".format(config_index)
         results = self.sql.execute_sql_command(command)
         if results:
@@ -103,9 +103,9 @@ class BenchmarkDBResource(object):
             }
         return results_dict
 
-    def get_env_by_index(self, index):
+    def _get_env_by_index(self, index):
         results_dict = dict()
-        env_index = self.get_spec_index(index, "test_env_index")
+        env_index = self._get_spec_index(index, "test_env_index")
         command = "SELECT * FROM _environment WHERE `index`={}".format(env_index)
         results = self.sql.execute_sql_command(command)
         if results:
@@ -120,9 +120,9 @@ class BenchmarkDBResource(object):
             }
         return results_dict
 
-    def get_summary_report_by_index(self, index):
+    def _get_summary_report_by_index(self, index):
         result_dict = dict()
-        report_index = self.get_spec_index(index, "summary_report_index")
+        report_index = self._get_spec_index(index, "summary_report_index")
         command = "SELECT * FROM _summary_test_results WHERE `index`={}".format(report_index)
         results = self.sql.execute_sql_command(command)
         if results:
@@ -155,13 +155,13 @@ class BenchmarkDBResource(object):
         return result_dict
 
     @staticmethod
-    def get_duration(start_time, end_time):
+    def _get_duration(start_time, end_time):
         duration = 0
         if start_time is not None and end_time is not None:
             duration = end_time - start_time
         return duration
 
-    def get_test_state(self, index):
+    def _get_test_state_by_index(self, index):
         result = None
         command = "SELECT state FROM _tests WHERE `index`={}".format(index)
         results = self.sql.execute_sql_command(command)
@@ -169,7 +169,7 @@ class BenchmarkDBResource(object):
             result = results[0][0]
         return result
 
-    def get_index_by_key(self, key):
+    def _get_index_by_key(self, key):
         result = None
         command = "SELECT `index` FROM _tests WHERE `key`='{}'".format(key)
         results = self.sql.execute_sql_command(command)
@@ -177,27 +177,146 @@ class BenchmarkDBResource(object):
             result = results[0][0]
         return result
 
-    def search_tests_by_group_key(self, group_key):
+    def _search_tests_by_group_key(self, group_key):
         sea_string = "SELECT * FROM _tests WHERE group_key='{}'".format(group_key)
         result = self.sql.execute_sql_command(sea_string)
         return result
 
-    def search_test_name(self, test_name):
+    def _search_test_name(self, test_name):
         sea_string = "SELECT * FROM _tests WHERE group_name='{}'".format(test_name)
         result = self.sql.execute_sql_command(sea_string)
         return result
 
-    def search_step_by_key(self, step_key):
+    def _search_step_by_key(self, step_key):
         sea_string = "SELECT * FROM _tests WHERE `key`='{}'".format(step_key)
         result = self.sql.execute_sql_command(sea_string)
         return result
 
     def confirm_test(self, step_key):
+        """
+
+        :param step_key:
+        :return:
+        """
         cmd = "UPDATE _tests SET confirmed=1 where `key`='{}'".format(step_key)
         self.sql.cursor.execute(cmd)
         self.sql.conn.commit()
 
     def confirm_group(self, group_key):
+        """
+        confirm whole group tests
+        :param group_key:
+        :return:
+        """
         cmd = "UPDATE _tests SET confirmed=1 where `group_key`='{}'".format(group_key)
         self.sql.cursor.execute(cmd)
-        self.sql.conn.commit()
\ No newline at end of file
+        self.sql.conn.commit()
+
+    def check_test_name(self, test_name):
+        """
+        check test is exit
+        :param test_name:
+        :return:
+        """
+        ret = self._search_test_name(test_name)
+        return ret
+
+    def search(self, test_key=None, project_name=None, begin_time=None, end_time=None, test_name=None):
+        """
+        :param project_name: project name, like tahoe, alpha
+        :param begin_time: format: '%Y%m%d', e.g. 20170601
+        :param end_time: format: '%Y%m%d', e.g. 201901101
+        :param test_name:
+        :param test_key:
+        :return:
+        """
+        test_results = list()
+        if test_key is None:
+            search_str = self._get_search_match_string(test_key, project_name, begin_time, end_time, test_name)
+            results = self.sql.execute_sql_command(search_str)
+            group_key_list = [item[4] for item in results if item[4] is not None]
+            group_key_list = list(set(group_key_list))
+        else:
+            group_key_list = test_key
+        for group_key in group_key_list:
+            results = self._search_tests_by_group_key(group_key)
+            test = {
+                "name": results[0][2],
+                "project_name": results[0][3].upper(),
+                "start_time": results[0][11],
+                "end_time": results[0][12],
+                "tester": results[0][14],
+                "test_key": group_key,
+                "environment": self._get_env_by_index(results[0][0]),
+                "confirm": results[0][15]
+            }
+            test_results.append(test)
+        return test_results
+
+    def get_test_detail_information(self, test_key):
+        """
+        get test detail information by test key
+        :param test_key:
+        :return:
+        """
+        results = self._search_tests_by_group_key(test_key)
+        test_steps = list()
+        for item in results:
+            step = {
+                "index":item[0],
+                "name":item[1],
+                "group_name": item[2],
+                "key":item[10],
+                "start_time":item[11],
+                "end_time":item[12],
+                "state":item[13],
+                "duration": self._get_duration(item[11], item[12]),
+                "environment": self._get_env_by_index(item[0]),
+                "summary_report": self._get_summary_report_by_index(item[0]),
+                "configuration": self._get_test_config(item[0])}
+            test_steps.append(step)
+        return test_steps
+
+    def get_step_detail_information(self, step_key):
+        """
+        get step detail information
+        :param step_key:
+        :return:
+        """
+        step = None
+        result = self._search_step_by_key(step_key)
+        if result:
+            result = result[0]
+            step = {
+                "index":result[0],
+                "name":result[1],
+                "group_name": result[2],
+                "key":result[10],
+                "start_time":result[11],
+                "end_time":result[12],
+                "state":result[13],
+                "duration":self._get_duration(result[11], result[12]),
+                "environment": self._get_env_by_index(result[0]),
+                "summary_report": self._get_summary_report_by_index(result[0]),
+                "configuration": self._get_test_config(result[0])}
+        return step
+
+    def get_real_time_results(self, key, mini_index=None):
+        """
+
+        :param key: the test which want to get the real time
+        :param mini_index: get the real time data index more then the mini_index
+        :return:
+        """
+        index = self._get_index_by_key(key)
+        result = self._get_real_time_results(index, mini_index)
+        return result
+
+    def get_test_state(self, key):
+        """
+        get test state by test key
+        :param key:
+        :return:
+        """
+        index = self._get_index_by_key(key)
+        return self._get_test_state_by_index(index)
